summaryrefslogtreecommitdiffstats
path: root/kbabel/catalogmanager/libsvn/svnhandler.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/catalogmanager/libsvn/svnhandler.h')
-rw-r--r--kbabel/catalogmanager/libsvn/svnhandler.h34
1 files changed, 18 insertions, 16 deletions
diff --git a/kbabel/catalogmanager/libsvn/svnhandler.h b/kbabel/catalogmanager/libsvn/svnhandler.h
index 82039421..cad3e93f 100644
--- a/kbabel/catalogmanager/libsvn/svnhandler.h
+++ b/kbabel/catalogmanager/libsvn/svnhandler.h
@@ -20,11 +20,11 @@
In addition, as a special exception, the copyright holders give
permission to link the code of this program with any edition of
- the Qt library by Trolltech AS, Norway (or with modified versions
- of Qt that use the same license as Qt), and distribute linked
+ the TQt library by Trolltech AS, Norway (or with modified versions
+ of TQt that use the same license as TQt), and distribute linked
combinations including the two. You must obey the GNU General
Public License in all respects for all of the code used other than
- Qt. If you modify this file, you may extend this exception to
+ TQt. If you modify this file, you may extend this exception to
your version of the file, but you are not obligated to do so. If
you do not wish to do so, delete this exception statement from
your version.
@@ -35,13 +35,13 @@
#ifndef SVNHANDLER_H
#define SVNHANDLER_H
// Qt include files
#include <tqmap.h>
#include <tqobject.h>
// Project specific include files
#include "svndialog.h"
#include "svnresources.h"
// Forwarding Qt classes
class TQString;
class TQStringList;
@@ -52,12 +52,13 @@ class KSharedConfig;
*
* @short Backend for SVN support in Catalog Manager
*/
-class SVNHandler : public QObject
+class SVNHandler : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
- enum FileStatus {
+ enum FiletqStatus {
NO_REPOSITORY,
NOT_IN_SVN,
LOCALLY_ADDED,
@@ -68,24 +69,24 @@ class SVNHandler : public QObject
ERROR_IN_WC ///< The working copy has data that cannot be handled
};
- SVNHandler( const TQString& poBaseDir = TQString::null, const TQString& potBaseDir = TQString::null );
+ SVNHandler( const TQString& poBaseDir = TQString(), const TQString& potBaseDir = TQString() );
void setPOBaseDir( const TQString& dir );
void setPOTBaseDir( const TQString& dir );
- FileStatus fstatus( const TQString& filename ) const;
- TQString fileStatus( const FileStatus status ) const;
- TQString svnStatus( const TQString& filename ) const;
+ FiletqStatus fstatus( const TQString& filename ) const;
+ TQString filetqStatus( const FiletqStatus status ) const;
+ TQString svntqStatus( const TQString& filename ) const;
- void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config );
- void execSVNCommand( TQWidget* parent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config );
+ void execSVNCommand( TQWidget* tqparent, SVN::Command cmd, const TQString& filename, bool templates, KSharedConfig* config );
+ void execSVNCommand( TQWidget* tqparent, SVN::Command cmd, const TQStringList& files, bool templates, KSharedConfig* config );
void setAutoUpdateTemplates( bool update );
/**
* True if the file was modified or has another status considered as a modification
*/
- bool isConsideredModified( const FileStatus status ) const;
+ bool isConsideredModified( const FiletqStatus status ) const;
signals:
void signalIsPORepository( bool );
@@ -93,7 +94,7 @@ class SVNHandler : public QObject
void signalFilesCommitted( const TQStringList& );
private:
- void showDialog( TQWidget* parent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config );
+ void showDialog( TQWidget* tqparent, SVN::Command cmd, const TQStringList& files, const TQString& commandLine, KSharedConfig* config );
/// Check quickly if the file is part of a SVN repository
bool isInSvn( const TQString& path );
void checkToAdd( const TQStringList& files );
@@ -112,9 +113,10 @@ class SVNHandler : public QObject
TQMap<TQString,TQString> map;
};
-class SVNOutputCollector: public QObject
+class SVNOutputCollector: public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
SVNOutputCollector( KProcess* );
@@ -35,13 +35,13 @@
#ifndef SVNHANDLER_H
#define SVNHANDLER_H
-// Qt include files
+// TQt include files
#include <tqmap.h>
#include <tqobject.h>
@@ -35,13 +35,13 @@
#include "svndialog.h"
#include "svnresources.h"
-// Forwarding Qt classes
+// Forwarding TQt classes
class TQString;
class TQStringList;